@@ -4,7 +4,7 @@
 #' @return output value (numeric)
 #' @export
 #' @examples
-#' # create a vector of integers (as works for non-integers)
+#' # create a vector of integers (also works for non-integers)
 #' set.seed(0)
 #' V = c(floor(runif(9, min=-3, max=3)))
 #' print(V)
@@ -21,5 +21,7 @@
 #' # 0.229511038 0.004203641 0.229511038 0.229511038 0.031060941
 #'
 
-SoftMax <- function(x)
-  exp(x)/sum(exp(x))
+SoftMax <- function(x) {
+  exp_x <- exp(x - max(x))
+  exp_x / sum(exp_x)
+}
